import 'dart:convert';

import 'package:flutter/foundation.dart';
import 'package:hive/hive.dart';
import 'package:http/http.dart' as http;
import 'package:oxen_wallet/src/node/digest_request.dart';

part 'node.g.dart';

@HiveType(typeId: 1)
class Node extends HiveObject {
  Node({@required this.uri, this.login, this.password});

  Node.fromMap(Map map)
      : uri = (map['uri'] ?? '') as String,
        login = map['login'] as String,
        password = map['password'] as String;

  static const boxName = 'Nodes';

  @HiveField(0)
  String uri;

  @HiveField(1)
  String login;

  @HiveField(2)
  String password;

  Future<bool> isOnline() async {
    final resBody = await sendRPCRequest('get_info');
    return !(resBody['result']['offline'] as bool);
  }

  Future<Map<String, dynamic>> sendRPCRequest(String method,
      {Map params}) async {



    Map<String, dynamic> resultBody;

    final requestBody = params != null
        ? {'jsonrpc': '2.0', 'id': '0', 'method': method, 'params': params}
        : {'jsonrpc': '2.0', 'id': '0', 'method': method};

    if (login != null && password != null) {
      final digestRequest = DigestRequest();
      final response = await digestRequest.request(
          uri: uri, login: login, password: password, requestBody: requestBody);
      resultBody = response.data as Map<String, dynamic>;
    } else {
      final url = Uri.http(uri, '/json_rpc');
      final headers = {'Content-type': 'application/json'};
      final body = json.encode(requestBody);
      print('Node Port: ${url.port}');
      final response =
          await http.post(url, headers: headers, body: body);
      resultBody = json.decode(response.body) as Map<String, dynamic>;
    }

    return resultBody;
  }
}
